@@ -6,7 +6,7 @@ import isString from 'lodash/isString';
 import { makeFieldParser } from '../utils/fieldParser';
 import { MutableVector, Vector } from '../types/vector';
 import { ArrayVector } from '../vector/ArrayVector';
-import { vectorToArray } from '../vector/vectorToArray';
+import { FunctionalVector } from '../vector/FunctionalVector';
 
 export type MutableField<T = any> = Field<T, MutableVector<T>>;
 
@@ -14,7 +14,7 @@ type MutableVectorCreator = (buffer?: any[]) => MutableVector;
 
 export const MISSING_VALUE: any = null;
 
-export class MutableDataFrame<T = any> implements DataFrame, MutableVector<T> {
+export class MutableDataFrame<T = any> extends FunctionalVector<T> implements DataFrame, MutableVector<T> {
   name?: string;
   refId?: string;
   meta?: QueryResultMeta;
@@ -26,6 +26,8 @@ export class MutableDataFrame<T = any> implements DataFrame, MutableVector<T> {
   private creator: MutableVectorCreator;
 
   constructor(source?: DataFrame | DataFrameDTO, creator?: MutableVectorCreator) {
+    super();
+
     // This creates the underlying storage buffers
     this.creator = creator
       ? creator
@@ -108,11 +110,11 @@ export class MutableDataFrame<T = any> implements DataFrame, MutableVector<T> {
     }
 
     const field: MutableField = {
+      ...f,
       name,
       type,
       config: f.config || {},
       values: this.creator(buffer),
-      labels: f.labels,
     };
 
     if (type === FieldType.other) {
@@ -150,7 +152,7 @@ export class MutableDataFrame<T = any> implements DataFrame, MutableVector<T> {
       return Math.max(v, f.values.length);
     }, 0);
 
-    // Add empty elements until everything mastches
+    // Add empty elements until everything matches
     for (const field of this.fields) {
       while (field.values.length !== length) {
         field.values.add(MISSING_VALUE);
@@ -231,11 +233,6 @@ export class MutableDataFrame<T = any> implements DataFrame, MutableVector<T> {
           field.parse = makeFieldParser(val, field);
         }
         val = field.parse(val);
-      } else if (field.type === FieldType.time && isArray(val)) {
-        if (!field.parse) {
-          field.parse = (val: any[]) => val[0] || undefined;
-        }
-        val = field.parse(val);
       }
 
       if (val === undefined) {
@@ -272,10 +269,6 @@ export class MutableDataFrame<T = any> implements DataFrame, MutableVector<T> {
     return v as T;
   }
 
-  toArray(): T[] {
-    return vectorToArray(this);
-  }
-
   /**
    * The simplified JSON values used in JSON.stringify()
    */
