@@ -7,6 +7,7 @@ import (
 	"github.com/grafana/grafana/pkg/bus"
 	"github.com/grafana/grafana/pkg/login/social"
 	"github.com/grafana/grafana/pkg/models"
+	"github.com/grafana/grafana/pkg/services/alerting"
 	"github.com/grafana/grafana/pkg/services/sqlstore"
 
 	"github.com/grafana/grafana/pkg/infra/log"
@@ -21,16 +22,19 @@ func init() {
 }
 
 type UsageStatsService struct {
-	Cfg      *setting.Cfg       `inject:""`
-	Bus      bus.Bus            `inject:""`
-	SQLStore *sqlstore.SqlStore `inject:""`
-	License  models.Licensing   `inject:""`
+	Cfg                *setting.Cfg               `inject:""`
+	Bus                bus.Bus                    `inject:""`
+	SQLStore           *sqlstore.SqlStore         `inject:""`
+	AlertingUsageStats alerting.UsageStatsQuerier `inject:""`
+	License            models.Licensing           `inject:""`
+
+	log log.Logger
 
 	oauthProviders map[string]bool
 }
 
 func (uss *UsageStatsService) Init() error {
-
+	uss.log = log.New("infra.usagestats")
 	uss.oauthProviders = social.GetOAuthProviders(uss.Cfg)
 	return nil
 }
